pub struct ChannelChain2 {
pub channel_id: String,
pub port_id: String,
}Fields
channel_id: Stringport_id: StringTrait Implementations
Sourceimpl Clone for ChannelChain2
impl Clone for ChannelChain2
Sourcefn clone(&self) -> ChannelChain2
fn clone(&self) -> ChannelChain2
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChannelChain2
impl Debug for ChannelChain2
Sourceimpl Default for ChannelChain2
impl Default for ChannelChain2
Sourcefn default() -> ChannelChain2
fn default() -> ChannelChain2
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ChannelChain2
impl<'de> Deserialize<'de> for ChannelChain2
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ChannelChain2
Sourceimpl JsonSchema for ChannelChain2
impl JsonSchema for ChannelChain2
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ChannelChain2
impl PartialEq for ChannelChain2
Sourcefn eq(&self, other: &ChannelChain2) -> bool
fn eq(&self, other: &ChannelChain2) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ChannelChain2
impl Serialize for ChannelChain2
impl StructuralPartialEq for ChannelChain2