pub struct Codebase {
pub git_repo: Option<String>,
pub recommended_version: Option<String>,
pub compatible_versions: Vec<String>,
}Fields
git_repo: Option<String>recommended_version: Option<String>compatible_versions: Vec<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Codebase
impl<'de> Deserialize<'de> for Codebase
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Codebase
Sourceimpl JsonSchema for Codebase
impl JsonSchema for Codebase
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for Codebase